# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/internal_redirect/safe_cross_scheme/v3/safe_cross_scheme_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVenvoy/extensions/internal_redirect/safe_cross_scheme/v3/safe_cross_scheme_config.proto\x12\x37\x65nvoy.extensions.internal_redirect.safe_cross_scheme.v3\x1a\x1dudpa/annotations/status.proto\"\x17\n\x15SafeCrossSchemeConfigB\xe1\x01\nEio.envoyproxy.envoy.extensions.internal_redirect.safe_cross_scheme.v3B\x1aSafeCrossSchemeConfigProtoP\x01Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/safe_cross_scheme/v3;safe_cross_schemev3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.internal_redirect.safe_cross_scheme.v3.safe_cross_scheme_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEio.envoyproxy.envoy.extensions.internal_redirect.safe_cross_scheme.v3B\032SafeCrossSchemeConfigProtoP\001Zrgithub.com/envoyproxy/go-control-plane/envoy/extensions/internal_redirect/safe_cross_scheme/v3;safe_cross_schemev3\272\200\310\321\006\002\020\002'
  _globals['_SAFECROSSSCHEMECONFIG']._serialized_start=178
  _globals['_SAFECROSSSCHEMECONFIG']._serialized_end=201
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/router/cluster_specifiers/lua/v3/lua.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;envoy/extensions/router/cluster_specifiers/lua/v3/lua.proto\x12\x31\x65nvoy.extensions.router.cluster_specifiers.lua.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"e\n\tLuaConfig\x12?\n\x0bsource_code\x18\x01 \x01(\x0b\x32 .envoy.config.core.v3.DataSourceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x17\n\x0f\x64\x65\x66\x61ult_cluster\x18\x02 \x01(\tB\xb5\x01\n?io.envoyproxy.envoy.extensions.router.cluster_specifiers.lua.v3B\x08LuaProtoP\x01Z^github.com/envoyproxy/go-control-plane/envoy/extensions/router/cluster_specifiers/lua/v3;luav3\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.router.cluster_specifiers.lua.v3.lua_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n?io.envoyproxy.envoy.extensions.router.cluster_specifiers.lua.v3B\010LuaProtoP\001Z^github.com/envoyproxy/go-control-plane/envoy/extensions/router/cluster_specifiers/lua/v3;luav3\272\200\310\321\006\002\020\002'
  _LUACONFIG.fields_by_name['source_code']._options = None
  _LUACONFIG.fields_by_name['source_code']._serialized_options = b'\372B\005\212\001\002\020\001'
  _globals['_LUACONFIG']._serialized_start=203
  _globals['_LUACONFIG']._serialized_end=304
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/network/generic_proxy/codecs/http1/v3/http1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJenvoy/extensions/filters/network/generic_proxy/codecs/http1/v3/http1.proto\x12>envoy.extensions.filters.network.generic_proxy.codecs.http1.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\x80\x01\n\x10Http1CodecConfig\x12\x35\n\x11single_frame_mode\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x0fmax_buffer_size\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\xdb\x01\nLio.envoyproxy.envoy.extensions.filters.network.generic_proxy.codecs.http1.v3B\nHttp1ProtoP\x01Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/codecs/http1/v3;http1v3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.network.generic_proxy.codecs.http1.v3.http1_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nLio.envoyproxy.envoy.extensions.filters.network.generic_proxy.codecs.http1.v3B\nHttp1ProtoP\001Zmgithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/network/generic_proxy/codecs/http1/v3;http1v3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_HTTP1CODECCONFIG']._serialized_start=239
  _globals['_HTTP1CODECCONFIG']._serialized_end=367
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from envoy.service.redis_auth.v3 import redis_external_auth_pb2 as envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2


class RedisProxyExternalAuthStub(object):
    """[#protodoc-title: Redis external authentication service]

    The messages used by the redis_proxy filter when performing external authentication.

    A generic interface for performing external password authentication on incoming AUTH commands.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Authenticate = channel.unary_unary(
                '/envoy.service.redis_auth.v3.RedisProxyExternalAuth/Authenticate',
                request_serializer=envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthRequest.SerializeToString,
                response_deserializer=envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthResponse.FromString,
                )


class RedisProxyExternalAuthServicer(object):
    """[#protodoc-title: Redis external authentication service]

    The messages used by the redis_proxy filter when performing external authentication.

    A generic interface for performing external password authentication on incoming AUTH commands.
    """

    def Authenticate(self, request, context):
        """Performs authentication check based on the data sent with the AUTH request.
        Returns either an OK status or an error status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RedisProxyExternalAuthServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Authenticate': grpc.unary_unary_rpc_method_handler(
                    servicer.Authenticate,
                    request_deserializer=envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthRequest.FromString,
                    response_serializer=envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'envoy.service.redis_auth.v3.RedisProxyExternalAuth', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RedisProxyExternalAuth(object):
    """[#protodoc-title: Redis external authentication service]

    The messages used by the redis_proxy filter when performing external authentication.

    A generic interface for performing external password authentication on incoming AUTH commands.
    """

    @staticmethod
    def Authenticate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/envoy.service.redis_auth.v3.RedisProxyExternalAuth/Authenticate',
            envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthRequest.SerializeToString,
            envoy_dot_service_dot_redis__auth_dot_v3_dot_redis__external__auth__pb2.RedisProxyExternalAuthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: xds/type/matcher/v3/domain.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from xds.type.matcher.v3 import matcher_pb2 as xds_dot_type_dot_matcher_dot_v3_dot_matcher__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n xds/type/matcher/v3/domain.proto\x12\x13xds.type.matcher.v3\x1a\x1fxds/annotations/v3/status.proto\x1a!xds/type/matcher/v3/matcher.proto\x1a\x17validate/validate.proto\"\xc6\x01\n\x11ServerNameMatcher\x12M\n\x0f\x64omain_matchers\x18\x01 \x03(\x0b\x32\x34.xds.type.matcher.v3.ServerNameMatcher.DomainMatcher\x1a\x62\n\rDomainMatcher\x12\x19\n\x07\x64omains\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x12\x36\n\x08on_match\x18\x02 \x01(\x0b\x32$.xds.type.matcher.v3.Matcher.OnMatchBn\n\x1e\x63om.github.xds.type.matcher.v3B\x16ServerNameMatcherProtoP\x01Z*github.com/cncf/xds/go/xds/type/matcher/v3\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'xds.type.matcher.v3.domain_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.github.xds.type.matcher.v3B\026ServerNameMatcherProtoP\001Z*github.com/cncf/xds/go/xds/type/matcher/v3\322\306\244\341\006\002\010\001'
  _SERVERNAMEMATCHER_DOMAINMATCHER.fields_by_name['domains']._options = None
  _SERVERNAMEMATCHER_DOMAINMATCHER.fields_by_name['domains']._serialized_options = b'\372B\005\222\001\002\010\001'
  _globals['_SERVERNAMEMATCHER']._serialized_start=151
  _globals['_SERVERNAMEMATCHER']._serialized_end=349
  _globals['_SERVERNAMEMATCHER_DOMAINMATCHER']._serialized_start=251
  _globals['_SERVERNAMEMATCHER_DOMAINMATCHER']._serialized_end=349
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/dynamic_modules/v3/dynamic_modules.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.extensions.dynamic_modules.v3 import dynamic_modules_pb2 as envoy_dot_extensions_dot_dynamic__modules_dot_v3_dot_dynamic__modules__pb2
from xds.annotations.v3 import status_pb2 as xds_dot_annotations_dot_v3_dot_status__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFenvoy/extensions/filters/http/dynamic_modules/v3/dynamic_modules.proto\x12\x30\x65nvoy.extensions.filters.http.dynamic_modules.v3\x1a\x39\x65nvoy/extensions/dynamic_modules/v3/dynamic_modules.proto\x1a\x1fxds/annotations/v3/status.proto\x1a\x1dudpa/annotations/status.proto\"\x9a\x01\n\x13\x44ynamicModuleFilter\x12W\n\x15\x64ynamic_module_config\x18\x01 \x01(\x0b\x32\x38.envoy.extensions.dynamic_modules.v3.DynamicModuleConfig\x12\x13\n\x0b\x66ilter_name\x18\x02 \x01(\t\x12\x15\n\rfilter_config\x18\x03 \x01(\tB\xd2\x01\n>io.envoyproxy.envoy.extensions.filters.http.dynamic_modules.v3B\x13\x44ynamicModulesProtoP\x01Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_modules/v3;dynamic_modulesv3\xba\x80\xc8\xd1\x06\x02\x10\x02\xd2\xc6\xa4\xe1\x06\x02\x08\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'envoy.extensions.filters.http.dynamic_modules.v3.dynamic_modules_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n>io.envoyproxy.envoy.extensions.filters.http.dynamic_modules.v3B\023DynamicModulesProtoP\001Zigithub.com/envoyproxy/go-control-plane/envoy/extensions/filters/http/dynamic_modules/v3;dynamic_modulesv3\272\200\310\321\006\002\020\002\322\306\244\341\006\002\010\001'
  _globals['_DYNAMICMODULEFILTER']._serialized_start=248
  _globals['_DYNAMICMODULEFILTER']._serialized_end=402
# @@protoc_insertion_point(module_scope)
